@@ -13,17 +13,17 @@ def main():
         base = os.path.basename(inputfile)
         base = os.path.splitext(base)
         label = base[0]
+        label = label.replace('-', '_')
         ext = base[1]
-        if ext == 'cube':
+        if ext == '.cube':
             volume, atoms = read_cube_data(inputfile)
             batoms = Batoms(label, atoms = atoms, volume=volume)
         else:
-            atoms = read(inputfile)
+            atoms = read(inputfile, ':')
             batoms = Batoms(label = label, atoms = atoms)
     batoms.model_type = batoms_input['model_type']
-    if atoms.pbc.any():
-      batoms_input['show_unit_cell'] = True
-    batoms.render.run(direction = [0, 0, 1], output_image = render_input['output_image'], 
+    batoms.set_frames()
+    batoms.render.run(direction = [0, 0, 1], output_image = render_input['output'], 
             run_render = render_input['run_render'])
 
 if __name__ == "__main__":
